@@ -30,6 +30,7 @@
 #include <openrct2/actions/WallRemoveAction.h>
 #include <openrct2/entity/Balloon.h>
 #include <openrct2/entity/Duck.h>
+#include <openrct2/entity/EntityList.h>
 #include <openrct2/entity/EntityRegistry.h>
 #include <openrct2/entity/Staff.h>
 #include <openrct2/localisation/Formatter.h>
@@ -44,7 +45,6 @@
 #include <openrct2/ride/RideData.h>
 #include <openrct2/ride/Track.h>
 #include <openrct2/ride/Vehicle.h>
-#include <openrct2/scenario/Scenario.h>
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/windows/Intent.h>
 #include <openrct2/world/Banner.h>
@@ -83,48 +83,48 @@ namespace OpenRCT2::Ui
     {
         InteractionInfo info{};
         // No click input for scenario editor or track manager
-        if (gScreenFlags & (SCREEN_FLAGS_SCENARIO_EDITOR | SCREEN_FLAGS_TRACK_MANAGER))
+        if (gLegacyScene == LegacyScene::scenarioEditor || gLegacyScene == LegacyScene::trackDesignsManager)
             return info;
 
         //
-        if ((gScreenFlags & SCREEN_FLAGS_TRACK_DESIGNER) && GetGameState().EditorStep != EditorStep::RollercoasterDesigner)
+        if (gLegacyScene == LegacyScene::trackDesigner && getGameState().editorStep != EditorStep::RollercoasterDesigner)
             return info;
 
         info = GetMapCoordinatesFromPos(
             screenCoords,
             EnumsToFlags(
-                ViewportInteractionItem::Entity, ViewportInteractionItem::Ride, ViewportInteractionItem::ParkEntrance));
-        auto tileElement = info.interactionType != ViewportInteractionItem::Entity ? info.Element : nullptr;
-        // Only valid when info.interactionType == ViewportInteractionItem::Entity, but can't assign nullptr without compiler
+                ViewportInteractionItem::entity, ViewportInteractionItem::ride, ViewportInteractionItem::parkEntrance));
+        auto tileElement = info.interactionType != ViewportInteractionItem::entity ? info.Element : nullptr;
+        // Only valid when info.interactionType == ViewportInteractionItem::entity, but can't assign nullptr without compiler
         // complaining
         auto sprite = info.Entity;
 
         // Allows only balloons to be popped and ducks to be quacked in title screen
-        if (gScreenFlags & SCREEN_FLAGS_TITLE_DEMO)
+        if (gLegacyScene == LegacyScene::titleSequence)
         {
-            if (info.interactionType == ViewportInteractionItem::Entity && (sprite->Is<Balloon>() || sprite->Is<Duck>()))
+            if (info.interactionType == ViewportInteractionItem::entity && (sprite->Is<Balloon>() || sprite->Is<Duck>()))
                 return info;
 
-            info.interactionType = ViewportInteractionItem::None;
+            info.interactionType = ViewportInteractionItem::none;
             return info;
         }
 
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::Entity:
+            case ViewportInteractionItem::entity:
                 switch (sprite->Type)
                 {
-                    case EntityType::Vehicle:
+                    case EntityType::vehicle:
                     {
                         auto vehicle = sprite->As<Vehicle>();
                         if (vehicle != nullptr && !vehicle->IsCableLift())
                             vehicle->SetMapToolbar();
                         else
-                            info.interactionType = ViewportInteractionItem::None;
+                            info.interactionType = ViewportInteractionItem::none;
                     }
                     break;
-                    case EntityType::Guest:
-                    case EntityType::Staff:
+                    case EntityType::guest:
+                    case EntityType::staff:
                     {
                         auto peep = sprite->As<Peep>();
                         if (peep != nullptr)
@@ -133,7 +133,7 @@ namespace OpenRCT2::Ui
                         }
                         else
                         {
-                            info.interactionType = ViewportInteractionItem::None;
+                            info.interactionType = ViewportInteractionItem::none;
                         }
                     }
                     break;
@@ -141,14 +141,14 @@ namespace OpenRCT2::Ui
                         break;
                 }
                 break;
-            case ViewportInteractionItem::Ride:
+            case ViewportInteractionItem::ride:
                 Guard::ArgumentNotNull(tileElement);
                 RideSetMapTooltip(*tileElement);
                 break;
-            case ViewportInteractionItem::ParkEntrance:
+            case ViewportInteractionItem::parkEntrance:
             {
-                auto& gameState = GetGameState();
-                auto parkName = gameState.Park.Name.c_str();
+                auto& gameState = getGameState();
+                auto parkName = gameState.park.name.c_str();
 
                 auto ft = Formatter();
                 ft.Add<StringId>(STR_STRING);
@@ -157,18 +157,18 @@ namespace OpenRCT2::Ui
                 break;
             }
             default:
-                info.interactionType = ViewportInteractionItem::None;
+                info.interactionType = ViewportInteractionItem::none;
                 break;
         }
 
         // If nothing is under cursor, find a close by peep
-        if (info.interactionType == ViewportInteractionItem::None)
+        if (info.interactionType == ViewportInteractionItem::none)
         {
             auto peep = ViewportInteractionGetClosestPeep(screenCoords, 32);
             if (peep != nullptr)
             {
                 info.Entity = peep;
-                info.interactionType = ViewportInteractionItem::Entity;
+                info.interactionType = ViewportInteractionItem::entity;
                 info.Loc.x = peep->x;
                 info.Loc.y = peep->y;
                 PeepSetMapTooltip(peep);
@@ -184,9 +184,9 @@ namespace OpenRCT2::Ui
 
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::Entity:
-            case ViewportInteractionItem::Ride:
-            case ViewportInteractionItem::ParkEntrance:
+            case ViewportInteractionItem::entity:
+            case ViewportInteractionItem::ride:
+            case ViewportInteractionItem::parkEntrance:
                 return true;
             default:
                 return false;
@@ -196,39 +196,40 @@ namespace OpenRCT2::Ui
     bool ViewportInteractionLeftClick(const ScreenCoordsXY& screenCoords)
     {
         auto info = ViewportInteractionGetItemLeft(screenCoords);
+        auto& gameState = getGameState();
 
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::Entity:
+            case ViewportInteractionItem::entity:
             {
                 auto entity = info.Entity;
                 switch (entity->Type)
                 {
-                    case EntityType::Vehicle:
+                    case EntityType::vehicle:
                     {
-                        auto intent = Intent(WD_VEHICLE);
+                        auto intent = Intent(WindowDetail::vehicle);
                         intent.PutExtra(INTENT_EXTRA_VEHICLE, entity);
                         ContextOpenIntent(&intent);
                         break;
                     }
-                    case EntityType::Guest:
-                    case EntityType::Staff:
+                    case EntityType::guest:
+                    case EntityType::staff:
                     {
-                        auto intent = Intent(WindowClass::Peep);
+                        auto intent = Intent(WindowClass::peep);
                         intent.PutExtra(INTENT_EXTRA_PEEP, entity);
                         ContextOpenIntent(&intent);
                         break;
                     }
-                    case EntityType::Balloon:
+                    case EntityType::balloon:
                     {
                         if (GameIsNotPaused())
                         {
-                            auto balloonPress = BalloonPressAction(entity->Id);
-                            GameActions::Execute(&balloonPress);
+                            auto balloonPress = GameActions::BalloonPressAction(entity->Id);
+                            GameActions::Execute(&balloonPress, gameState);
                         }
                     }
                     break;
-                    case EntityType::Duck:
+                    case EntityType::duck:
                     {
                         if (GameIsNotPaused())
                         {
@@ -245,15 +246,15 @@ namespace OpenRCT2::Ui
                 }
                 return true;
             }
-            case ViewportInteractionItem::Ride:
+            case ViewportInteractionItem::ride:
             {
-                auto intent = Intent(WD_TRACK);
+                auto intent = Intent(WindowDetail::track);
                 intent.PutExtra(INTENT_EXTRA_TILE_ELEMENT, info.Element);
                 ContextOpenIntent(&intent);
                 return true;
             }
-            case ViewportInteractionItem::ParkEntrance:
-                ContextOpenWindow(WindowClass::ParkInformation);
+            case ViewportInteractionItem::parkEntrance:
+                ContextOpenWindow(WindowClass::parkInformation);
                 return true;
             default:
                 return false;
@@ -270,66 +271,66 @@ namespace OpenRCT2::Ui
         int32_t i;
         InteractionInfo info{};
         // No click input for title screen or track manager
-        if (gScreenFlags & (SCREEN_FLAGS_TITLE_DEMO | SCREEN_FLAGS_TRACK_MANAGER))
+        if (gLegacyScene == LegacyScene::titleSequence || gLegacyScene == LegacyScene::trackDesignsManager)
             return info;
 
         //
-        if ((gScreenFlags & SCREEN_FLAGS_TRACK_DESIGNER) && GetGameState().EditorStep != EditorStep::RollercoasterDesigner)
+        if (gLegacyScene == LegacyScene::trackDesigner && getGameState().editorStep != EditorStep::RollercoasterDesigner)
             return info;
 
         constexpr auto flags = static_cast<int32_t>(
-            ~EnumsToFlags(ViewportInteractionItem::Terrain, ViewportInteractionItem::Water));
+            ~EnumsToFlags(ViewportInteractionItem::terrain, ViewportInteractionItem::water));
         info = GetMapCoordinatesFromPos(screenCoords, flags);
         auto tileElement = info.Element;
 
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::Entity:
+            case ViewportInteractionItem::entity:
             {
                 auto sprite = info.Entity;
-                if ((gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) || sprite->Type != EntityType::Vehicle)
+                if (gLegacyScene == LegacyScene::scenarioEditor || sprite->Type != EntityType::vehicle)
                 {
-                    info.interactionType = ViewportInteractionItem::None;
+                    info.interactionType = ViewportInteractionItem::none;
                     return info;
                 }
 
                 auto vehicle = sprite->As<Vehicle>();
                 if (vehicle == nullptr)
                 {
-                    info.interactionType = ViewportInteractionItem::None;
+                    info.interactionType = ViewportInteractionItem::none;
                     return info;
                 }
                 ride = GetRide(vehicle->ride);
-                if (ride != nullptr && ride->status == RideStatus::Closed)
+                if (ride != nullptr && ride->status == RideStatus::closed)
                 {
                     auto ft = Formatter();
                     ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_MODIFY);
-                    ride->FormatNameTo(ft);
+                    ride->formatNameTo(ft);
                     SetMapTooltip(ft);
                 }
                 return info;
             }
-            case ViewportInteractionItem::Ride:
+            case ViewportInteractionItem::ride:
             {
-                if (gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR)
+                if (gLegacyScene == LegacyScene::scenarioEditor)
                 {
-                    info.interactionType = ViewportInteractionItem::None;
+                    info.interactionType = ViewportInteractionItem::none;
                     return info;
                 }
                 if (tileElement->GetType() == TileElementType::Path)
                 {
-                    info.interactionType = ViewportInteractionItem::None;
+                    info.interactionType = ViewportInteractionItem::none;
                     return info;
                 }
 
                 ride = GetRide(tileElement->GetRideIndex());
                 if (ride == nullptr)
                 {
-                    info.interactionType = ViewportInteractionItem::None;
+                    info.interactionType = ViewportInteractionItem::none;
                     return info;
                 }
 
-                if (ride->status != RideStatus::Closed)
+                if (ride->status != RideStatus::closed)
                     return info;
 
                 auto ft = Formatter();
@@ -340,7 +341,7 @@ namespace OpenRCT2::Ui
                     StringId stringId;
                     if (tileElement->AsEntrance()->GetEntranceType() == ENTRANCE_TYPE_RIDE_ENTRANCE)
                     {
-                        if (ride->num_stations > 1)
+                        if (ride->numStations > 1)
                         {
                             stringId = STR_RIDE_STATION_X_ENTRANCE;
                         }
@@ -351,7 +352,7 @@ namespace OpenRCT2::Ui
                     }
                     else
                     {
-                        if (ride->num_stations > 1)
+                        if (ride->numStations > 1)
                         {
                             stringId = STR_RIDE_STATION_X_EXIT;
                         }
@@ -365,7 +366,7 @@ namespace OpenRCT2::Ui
                 else if (tileElement->AsTrack()->IsStation())
                 {
                     StringId stringId;
-                    if (ride->num_stations > 1)
+                    if (ride->numStations > 1)
                     {
                         stringId = STR_RIDE_STATION_X;
                     }
@@ -378,19 +379,19 @@ namespace OpenRCT2::Ui
                 else
                 {
                     // FIXME: Why does it *2 the value?
-                    if (!GetGameState().Cheats.sandboxMode && !MapIsLocationOwned({ info.Loc, tileElement->GetBaseZ() * 2 }))
+                    if (!getGameState().cheats.sandboxMode && !MapIsLocationOwned({ info.Loc, tileElement->GetBaseZ() * 2 }))
                     {
-                        info.interactionType = ViewportInteractionItem::None;
+                        info.interactionType = ViewportInteractionItem::none;
                         return info;
                     }
 
-                    ride->FormatNameTo(ft);
+                    ride->formatNameTo(ft);
                     return info;
                 }
 
-                ride->FormatNameTo(ft);
+                ride->formatNameTo(ft);
 
-                const auto& rtd = ride->GetRideTypeDescriptor();
+                const auto& rtd = ride->getRideTypeDescriptor();
                 ft.Add<StringId>(GetRideComponentName(rtd.NameConvention.station).capitalised);
 
                 StationIndex::UnderlyingType stationIndex;
@@ -400,24 +401,24 @@ namespace OpenRCT2::Ui
                     stationIndex = tileElement->AsTrack()->GetStationIndex().ToUnderlying();
 
                 for (i = stationIndex; i >= 0; i--)
-                    if (ride->GetStations()[i].Start.IsNull())
+                    if (ride->getStations()[i].Start.IsNull())
                         stationIndex--;
                 stationIndex++;
                 ft.Add<uint16_t>(stationIndex);
                 SetMapTooltip(ft);
                 return info;
             }
-            case ViewportInteractionItem::Wall:
+            case ViewportInteractionItem::wall:
             {
                 auto* wallEntry = tileElement->AsWall()->GetEntry();
-                if (wallEntry->scrolling_mode != SCROLLING_MODE_NONE)
+                if (wallEntry->scrolling_mode != kScrollingModeNone)
                 {
                     auto banner = tileElement->AsWall()->GetBanner();
                     if (banner != nullptr)
                     {
                         auto ft = Formatter();
                         ft.Add<StringId>(STR_MAP_TOOLTIP_BANNER_STRINGID_STRINGID);
-                        banner->FormatTextTo(ft);
+                        banner->formatTextTo(ft);
                         ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_MODIFY);
                         ft.Add<StringId>(wallEntry->name);
                         SetMapTooltip(ft);
@@ -426,17 +427,17 @@ namespace OpenRCT2::Ui
                 }
                 break;
             }
-            case ViewportInteractionItem::LargeScenery:
+            case ViewportInteractionItem::largeScenery:
             {
                 auto* sceneryEntry = tileElement->AsLargeScenery()->GetEntry();
-                if (sceneryEntry->scrolling_mode != SCROLLING_MODE_NONE)
+                if (sceneryEntry->scrolling_mode != kScrollingModeNone)
                 {
                     auto banner = tileElement->AsLargeScenery()->GetBanner();
                     if (banner != nullptr)
                     {
                         auto ft = Formatter();
                         ft.Add<StringId>(STR_MAP_TOOLTIP_BANNER_STRINGID_STRINGID);
-                        banner->FormatTextTo(ft);
+                        banner->formatTextTo(ft);
                         ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_MODIFY);
                         ft.Add<StringId>(sceneryEntry->name);
                         SetMapTooltip(ft);
@@ -445,7 +446,7 @@ namespace OpenRCT2::Ui
                 }
                 break;
             }
-            case ViewportInteractionItem::Banner:
+            case ViewportInteractionItem::banner:
             {
                 auto banner = tileElement->AsBanner()->GetBanner();
                 if (banner != nullptr)
@@ -454,7 +455,7 @@ namespace OpenRCT2::Ui
 
                     auto ft = Formatter();
                     ft.Add<StringId>(STR_MAP_TOOLTIP_BANNER_STRINGID_STRINGID);
-                    banner->FormatTextTo(ft, /*addColour*/ true);
+                    banner->formatTextWithColourTo(ft);
                     ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_MODIFY);
                     ft.Add<StringId>(bannerEntry->name);
                     SetMapTooltip(ft);
@@ -466,13 +467,13 @@ namespace OpenRCT2::Ui
                 break;
         }
 
-        if (!(InputTestFlag(INPUT_FLAG_6)) || !(InputTestFlag(INPUT_FLAG_TOOL_ACTIVE)))
+        if (!gInputFlags.has(InputFlag::unk6) || !gInputFlags.has(InputFlag::toolActive))
         {
             auto* windowMgr = GetWindowManager();
-            if (windowMgr->FindByClass(WindowClass::RideConstruction) == nullptr
-                && windowMgr->FindByClass(WindowClass::Footpath) == nullptr)
+            if (windowMgr->FindByClass(WindowClass::rideConstruction) == nullptr
+                && windowMgr->FindByClass(WindowClass::footpath) == nullptr)
             {
-                info.interactionType = ViewportInteractionItem::None;
+                info.interactionType = ViewportInteractionItem::none;
                 return info;
             }
         }
@@ -480,7 +481,7 @@ namespace OpenRCT2::Ui
         auto ft = Formatter();
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::Scenery:
+            case ViewportInteractionItem::scenery:
             {
                 auto* sceneryEntry = tileElement->AsSmallScenery()->GetEntry();
                 ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_REMOVE);
@@ -488,7 +489,7 @@ namespace OpenRCT2::Ui
                 SetMapTooltip(ft);
                 return info;
             }
-            case ViewportInteractionItem::Footpath:
+            case ViewportInteractionItem::footpath:
                 ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_REMOVE);
                 if (tileElement->AsPath()->IsQueue())
                     ft.Add<StringId>(STR_QUEUE_LINE_MAP_TIP);
@@ -497,7 +498,7 @@ namespace OpenRCT2::Ui
                 SetMapTooltip(ft);
                 return info;
 
-            case ViewportInteractionItem::PathAddition:
+            case ViewportInteractionItem::pathAddition:
             {
                 auto* pathAddEntry = tileElement->AsPath()->GetAdditionEntry();
                 ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_REMOVE);
@@ -509,8 +510,8 @@ namespace OpenRCT2::Ui
                 SetMapTooltip(ft);
                 return info;
             }
-            case ViewportInteractionItem::ParkEntrance:
-                if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !GetGameState().Cheats.sandboxMode)
+            case ViewportInteractionItem::parkEntrance:
+                if (gLegacyScene != LegacyScene::scenarioEditor && !getGameState().cheats.sandboxMode)
                     break;
 
                 if (tileElement->GetType() != TileElementType::Entrance)
@@ -521,7 +522,7 @@ namespace OpenRCT2::Ui
                 SetMapTooltip(ft);
                 return info;
 
-            case ViewportInteractionItem::Wall:
+            case ViewportInteractionItem::wall:
             {
                 auto* wallEntry = tileElement->AsWall()->GetEntry();
                 ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_REMOVE);
@@ -529,7 +530,7 @@ namespace OpenRCT2::Ui
                 SetMapTooltip(ft);
                 return info;
             }
-            case ViewportInteractionItem::LargeScenery:
+            case ViewportInteractionItem::largeScenery:
             {
                 auto* sceneryEntry = tileElement->AsLargeScenery()->GetEntry();
                 ft.Add<StringId>(STR_MAP_TOOLTIP_STRINGID_CLICK_TO_REMOVE);
@@ -541,7 +542,7 @@ namespace OpenRCT2::Ui
                 break;
         }
 
-        info.interactionType = ViewportInteractionItem::None;
+        info.interactionType = ViewportInteractionItem::none;
         return info;
     }
 
@@ -549,7 +550,7 @@ namespace OpenRCT2::Ui
     {
         auto info = ViewportInteractionGetItemRight(screenCoords);
 
-        return info.interactionType != ViewportInteractionItem::None;
+        return info.interactionType != ViewportInteractionItem::none;
     }
 
     /**
@@ -563,16 +564,16 @@ namespace OpenRCT2::Ui
 
         switch (info.interactionType)
         {
-            case ViewportInteractionItem::None:
-            case ViewportInteractionItem::Terrain:
-            case ViewportInteractionItem::Water:
-            case ViewportInteractionItem::Label:
+            case ViewportInteractionItem::none:
+            case ViewportInteractionItem::terrain:
+            case ViewportInteractionItem::water:
+            case ViewportInteractionItem::label:
                 return false;
 
-            case ViewportInteractionItem::Entity:
+            case ViewportInteractionItem::entity:
             {
                 auto entity = info.Entity;
-                if (entity->Type == EntityType::Vehicle)
+                if (entity->Type == EntityType::vehicle)
                 {
                     auto vehicle = entity->As<Vehicle>();
                     if (vehicle == nullptr)
@@ -587,30 +588,30 @@ namespace OpenRCT2::Ui
                 }
             }
             break;
-            case ViewportInteractionItem::Ride:
+            case ViewportInteractionItem::ride:
                 tileElement = { info.Loc, info.Element };
                 RideModify(tileElement);
                 break;
-            case ViewportInteractionItem::Scenery:
+            case ViewportInteractionItem::scenery:
                 ViewportInteractionRemoveScenery(*info.Element->AsSmallScenery(), info.Loc);
                 break;
-            case ViewportInteractionItem::Footpath:
+            case ViewportInteractionItem::footpath:
                 ViewportInteractionRemoveFootpath(*info.Element->AsPath(), info.Loc);
                 break;
-            case ViewportInteractionItem::PathAddition:
+            case ViewportInteractionItem::pathAddition:
                 ViewportInteractionRemovePathAddition(*info.Element->AsPath(), info.Loc);
                 break;
-            case ViewportInteractionItem::ParkEntrance:
+            case ViewportInteractionItem::parkEntrance:
                 ViewportInteractionRemoveParkEntrance(*info.Element->AsEntrance(), info.Loc);
                 break;
-            case ViewportInteractionItem::Wall:
+            case ViewportInteractionItem::wall:
                 ViewportInteractionRemoveParkWall(*info.Element->AsWall(), info.Loc);
                 break;
-            case ViewportInteractionItem::LargeScenery:
+            case ViewportInteractionItem::largeScenery:
                 ViewportInteractionRemoveLargeScenery(*info.Element->AsLargeScenery(), info.Loc);
                 break;
-            case ViewportInteractionItem::Banner:
-                ContextOpenDetailWindow(WD_BANNER, info.Element->AsBanner()->GetIndex().ToUnderlying());
+            case ViewportInteractionItem::banner:
+                ContextOpenDetailWindow(WindowDetail::banner, info.Element->AsBanner()->GetIndex().ToUnderlying());
                 break;
         }
 
@@ -623,11 +624,11 @@ namespace OpenRCT2::Ui
      */
     static void ViewportInteractionRemoveScenery(const SmallSceneryElement& smallSceneryElement, const CoordsXY& mapCoords)
     {
-        auto removeSceneryAction = SmallSceneryRemoveAction(
+        auto removeSceneryAction = GameActions::SmallSceneryRemoveAction(
             { mapCoords.x, mapCoords.y, smallSceneryElement.GetBaseZ() }, smallSceneryElement.GetSceneryQuadrant(),
             smallSceneryElement.GetEntryIndex());
 
-        GameActions::Execute(&removeSceneryAction);
+        GameActions::Execute(&removeSceneryAction, getGameState());
     }
 
     /**
@@ -637,7 +638,7 @@ namespace OpenRCT2::Ui
     static void ViewportInteractionRemoveFootpath(const PathElement& pathElement, const CoordsXY& mapCoords)
     {
         auto* windowMgr = GetWindowManager();
-        WindowBase* w = windowMgr->FindByClass(WindowClass::Footpath);
+        WindowBase* w = windowMgr->FindByClass(WindowClass::footpath);
         if (w != nullptr)
             FootpathUpdateProvisional();
 
@@ -650,8 +651,8 @@ namespace OpenRCT2::Ui
         {
             if (tileElement2->GetType() == TileElementType::Path && tileElement2->GetBaseZ() == z)
             {
-                auto action = FootpathRemoveAction({ mapCoords, z });
-                GameActions::Execute(&action);
+                auto action = GameActions::FootpathRemoveAction({ mapCoords, z });
+                GameActions::Execute(&action, getGameState());
                 break;
             }
         } while (!(tileElement2++)->IsLastForTile());
@@ -663,8 +664,9 @@ namespace OpenRCT2::Ui
      */
     static void ViewportInteractionRemovePathAddition(const PathElement& pathElement, const CoordsXY& mapCoords)
     {
-        auto footpathAdditionRemoveAction = FootpathAdditionRemoveAction({ mapCoords.x, mapCoords.y, pathElement.GetBaseZ() });
-        GameActions::Execute(&footpathAdditionRemoveAction);
+        auto footpathAdditionRemoveAction = GameActions::FootpathAdditionRemoveAction(
+            { mapCoords.x, mapCoords.y, pathElement.GetBaseZ() });
+        GameActions::Execute(&footpathAdditionRemoveAction, getGameState());
     }
 
     /**
@@ -683,8 +685,9 @@ namespace OpenRCT2::Ui
                 mapCoords -= CoordsDirectionDelta[rotation];
                 break;
         }
-        auto parkEntranceRemoveAction = ParkEntranceRemoveAction({ mapCoords.x, mapCoords.y, entranceElement.GetBaseZ() });
-        GameActions::Execute(&parkEntranceRemoveAction);
+        auto parkEntranceRemoveAction = GameActions::ParkEntranceRemoveAction(
+            { mapCoords.x, mapCoords.y, entranceElement.GetBaseZ() });
+        GameActions::Execute(&parkEntranceRemoveAction, getGameState());
     }
 
     /**
@@ -694,15 +697,15 @@ namespace OpenRCT2::Ui
     static void ViewportInteractionRemoveParkWall(const WallElement& wallElement, const CoordsXY& mapCoords)
     {
         auto* wallEntry = wallElement.GetEntry();
-        if (wallEntry->scrolling_mode != SCROLLING_MODE_NONE)
+        if (wallEntry->scrolling_mode != kScrollingModeNone)
         {
-            ContextOpenDetailWindow(WD_SIGN_SMALL, wallElement.GetBannerIndex().ToUnderlying());
+            ContextOpenDetailWindow(WindowDetail::signSmall, wallElement.GetBannerIndex().ToUnderlying());
         }
         else
         {
             CoordsXYZD wallLocation = { mapCoords.x, mapCoords.y, wallElement.GetBaseZ(), wallElement.GetDirection() };
-            auto wallRemoveAction = WallRemoveAction(wallLocation);
-            GameActions::Execute(&wallRemoveAction);
+            auto wallRemoveAction = GameActions::WallRemoveAction(wallLocation);
+            GameActions::Execute(&wallRemoveAction, getGameState());
         }
     }
 
@@ -714,17 +717,17 @@ namespace OpenRCT2::Ui
     {
         auto* sceneryEntry = largeSceneryElement.GetEntry();
 
-        if (sceneryEntry->scrolling_mode != SCROLLING_MODE_NONE)
+        if (sceneryEntry->scrolling_mode != kScrollingModeNone)
         {
             auto bannerIndex = largeSceneryElement.GetBannerIndex();
-            ContextOpenDetailWindow(WD_SIGN, bannerIndex.ToUnderlying());
+            ContextOpenDetailWindow(WindowDetail::sign, bannerIndex.ToUnderlying());
         }
         else
         {
-            auto removeSceneryAction = LargeSceneryRemoveAction(
+            auto removeSceneryAction = GameActions::LargeSceneryRemoveAction(
                 { mapCoords.x, mapCoords.y, largeSceneryElement.GetBaseZ(), largeSceneryElement.GetDirection() },
                 largeSceneryElement.GetSequenceIndex());
-            GameActions::Execute(&removeSceneryAction);
+            GameActions::Execute(&removeSceneryAction, getGameState());
         }
     }
 
@@ -799,17 +802,17 @@ namespace OpenRCT2::Ui
         }
         auto viewport = window->viewport;
         auto info = GetMapCoordinatesFromPosWindow(
-            window, screenCoords, EnumsToFlags(ViewportInteractionItem::Terrain, ViewportInteractionItem::Water));
+            window, screenCoords, EnumsToFlags(ViewportInteractionItem::terrain, ViewportInteractionItem::water));
         auto initialPos = info.Loc;
 
-        if (info.interactionType == ViewportInteractionItem::None)
+        if (info.interactionType == ViewportInteractionItem::none)
         {
             initialPos.SetNull();
             return initialPos;
         }
 
         int16_t waterHeight = 0;
-        if (info.interactionType == ViewportInteractionItem::Water)
+        if (info.interactionType == ViewportInteractionItem::water)
         {
             waterHeight = info.Element->AsSurface()->GetWaterHeight();
         }
@@ -820,7 +823,7 @@ namespace OpenRCT2::Ui
         for (int32_t i = 0; i < 5; i++)
         {
             int16_t z = waterHeight;
-            if (info.interactionType != ViewportInteractionItem::Water)
+            if (info.interactionType != ViewportInteractionItem::water)
             {
                 z = TileElementHeight(mapPos);
             }
