@@ -20,6 +20,8 @@
 #include "../management/Finance.h"
 #include "../ride/RideData.h"
 #include "../windows/Intent.h"
+#include "../world/Map.h"
+#include "../world/MapSelection.h"
 #include "../world/Park.h"
 #include "../world/Scenery.h"
 #include "../world/SurfaceData.h"
@@ -30,7 +32,7 @@
 
 namespace OpenRCT2::GameActions
 {
-    LandSmoothAction::LandSmoothAction(const CoordsXY& coords, MapRange range, uint8_t selectionType, bool isLowering)
+    LandSmoothAction::LandSmoothAction(const CoordsXY& coords, MapRange range, MapSelectType selectionType, bool isLowering)
         : _coords(coords)
         , _range(range)
         , _selectionType(selectionType)
@@ -58,18 +60,18 @@ namespace OpenRCT2::GameActions
         stream << DS_TAG(_coords) << DS_TAG(_range) << DS_TAG(_selectionType) << DS_TAG(_isLowering);
     }
 
-    Result LandSmoothAction::Query() const
+    Result LandSmoothAction::Query(GameState_t& gameState) const
     {
-        return SmoothLand(false);
+        return SmoothLand(gameState, false);
     }
 
-    Result LandSmoothAction::Execute() const
+    Result LandSmoothAction::Execute(GameState_t& gameState) const
     {
-        return SmoothLand(true);
+        return SmoothLand(gameState, true);
     }
 
     Result LandSmoothAction::SmoothLandTile(
-        int32_t direction, bool isExecuting, const CoordsXY& loc, SurfaceElement* surfaceElement) const
+        GameState_t& gameState, int32_t direction, bool isExecuting, const CoordsXY& loc, SurfaceElement* surfaceElement) const
     {
         int32_t targetBaseZ = surfaceElement->BaseHeight;
         int32_t slope = surfaceElement->GetSlope();
@@ -94,14 +96,15 @@ namespace OpenRCT2::GameActions
 
         auto landSetHeightAction = LandSetHeightAction(loc, targetBaseZ, slope);
         landSetHeightAction.SetFlags(GetFlags());
-        auto res = isExecuting ? ExecuteNested(&landSetHeightAction) : QueryNested(&landSetHeightAction);
+        auto res = isExecuting ? ExecuteNested(&landSetHeightAction, gameState) : QueryNested(&landSetHeightAction, gameState);
 
         return res;
     }
 
     money64 LandSmoothAction::SmoothLandRowByEdge(
-        bool isExecuting, const CoordsXY& loc, int32_t expectedLandHeight1, int32_t expectedLandHeight2, int32_t stepX,
-        int32_t stepY, int32_t direction1, int32_t direction2, int32_t checkDirection1, int32_t checkDirection2) const
+        GameState_t& gameState, bool isExecuting, const CoordsXY& loc, int32_t expectedLandHeight1, int32_t expectedLandHeight2,
+        int32_t stepX, int32_t stepY, int32_t direction1, int32_t direction2, int32_t checkDirection1,
+        int32_t checkDirection2) const
     {
         uint8_t shouldContinue = 0xF;
         int32_t landChangePerTile = _isLowering ? 2 : -2;
@@ -233,7 +236,8 @@ namespace OpenRCT2::GameActions
             }
             auto landSetHeightAction = LandSetHeightAction(nextLoc, targetBaseZ, slope);
             landSetHeightAction.SetFlags(GetFlags());
-            auto res = isExecuting ? ExecuteNested(&landSetHeightAction) : QueryNested(&landSetHeightAction);
+            auto res = isExecuting ? ExecuteNested(&landSetHeightAction, gameState)
+                                   : QueryNested(&landSetHeightAction, gameState);
             if (res.Error == Status::Ok)
             {
                 totalCost += res.Cost;
@@ -243,8 +247,8 @@ namespace OpenRCT2::GameActions
     }
 
     money64 LandSmoothAction::SmoothLandRowByCorner(
-        bool isExecuting, const CoordsXY& loc, int32_t expectedLandHeight, int32_t stepX, int32_t stepY, int32_t direction,
-        int32_t checkDirection) const
+        GameState_t& gameState, bool isExecuting, const CoordsXY& loc, int32_t expectedLandHeight, int32_t stepX, int32_t stepY,
+        int32_t direction, int32_t checkDirection) const
     {
         bool shouldContinue = true;
         money64 totalCost = 0;
@@ -313,15 +317,15 @@ namespace OpenRCT2::GameActions
             if (stepX * stepY != 0)
             {
                 totalCost += SmoothLandRowByCorner(
-                    isExecuting, nextLoc, expectedLandHeight + (landChangePerTile / 2), 0, stepY, direction,
+                    gameState, isExecuting, nextLoc, expectedLandHeight + (landChangePerTile / 2), 0, stepY, direction,
                     checkDirection ^ 3);
                 totalCost += SmoothLandRowByCorner(
-                    isExecuting, nextLoc, expectedLandHeight + (landChangePerTile / 2), stepX, 0, direction,
+                    gameState, isExecuting, nextLoc, expectedLandHeight + (landChangePerTile / 2), stepX, 0, direction,
                     checkDirection ^ 1);
             }
             expectedLandHeight += landChangePerTile;
             // change land of current tile
-            auto result = SmoothLandTile(direction, isExecuting, nextLoc, surfaceElement);
+            auto result = SmoothLandTile(gameState, direction, isExecuting, nextLoc, surfaceElement);
             if (result.Error == Status::Ok)
             {
                 totalCost += result.Cost;
@@ -330,18 +334,18 @@ namespace OpenRCT2::GameActions
         return totalCost;
     }
 
-    Result LandSmoothAction::SmoothLand(bool isExecuting) const
+    Result LandSmoothAction::SmoothLand(GameState_t& gameState, bool isExecuting) const
     {
         const bool raiseLand = !_isLowering;
-        const int32_t selectionType = _selectionType;
+        const auto selectionType = _selectionType;
         const int32_t heightOffset = raiseLand ? 2 : -2;
 
         auto normRange = _range.Normalise();
         // Cap bounds to map
-        auto l = std::max(normRange.GetLeft(), 32);
-        auto t = std::max(normRange.GetTop(), 32);
-        auto r = std::clamp(normRange.GetRight(), 0, kMaximumTileStartXY);
-        auto b = std::clamp(normRange.GetBottom(), 0, kMaximumTileStartXY);
+        auto l = std::max(normRange.GetX1(), 32);
+        auto t = std::max(normRange.GetY1(), 32);
+        auto r = std::clamp(normRange.GetX2(), 0, kMaximumTileStartXY);
+        auto b = std::clamp(normRange.GetY2(), 0, kMaximumTileStartXY);
         auto validRange = MapRange{ l, t, r, b };
 
         int32_t centreZ = TileElementHeight(_coords);
@@ -354,120 +358,125 @@ namespace OpenRCT2::GameActions
         // Do the smoothing
         switch (selectionType)
         {
-            case MAP_SELECT_TYPE_FULL:
+            case MapSelectType::full:
             {
                 uint8_t minHeight = heightOffset + MapGetLowestLandHeight(validRange);
                 uint8_t maxHeight = heightOffset + MapGetHighestLandHeight(validRange);
 
                 // Smooth the 4 corners
                 { // top-left
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetLeft(), validRange.GetTop() });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX1(), validRange.GetY1() });
                     if (surfaceElement != nullptr)
                     {
                         int32_t z = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 2)), minHeight, maxHeight);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, -32, 0, 2);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, -32, 0, 2);
                     }
                 }
                 { // bottom-left
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetLeft(), validRange.GetBottom() });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX1(), validRange.GetY2() });
                     if (surfaceElement != nullptr)
                     {
                         int32_t z = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 3)), minHeight, maxHeight);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetBottom() }, z, -32, 32, 1, 3);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY2() }, z, -32, 32, 1, 3);
                     }
                 }
                 { // bottom-right
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetRight(), validRange.GetBottom() });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX2(), validRange.GetY2() });
                     if (surfaceElement != nullptr)
                     {
                         int32_t z = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 0)), minHeight, maxHeight);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetRight(), validRange.GetBottom() }, z, 32, 32, 2, 0);
+                            gameState, isExecuting, { validRange.GetX2(), validRange.GetY2() }, z, 32, 32, 2, 0);
                     }
                 }
                 { // top-right
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetRight(), validRange.GetTop() });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX2(), validRange.GetY1() });
                     if (surfaceElement != nullptr)
                     {
                         int32_t z = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 1)), minHeight, maxHeight);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetRight(), validRange.GetTop() }, z, 32, -32, 3, 1);
+                            gameState, isExecuting, { validRange.GetX2(), validRange.GetY1() }, z, 32, -32, 3, 1);
                     }
                 }
 
                 // Smooth the edges
                 int32_t z1, z2;
-                for (int32_t y = validRange.GetTop(); y <= validRange.GetBottom(); y += kCoordsXYStep)
+                for (int32_t y = validRange.GetY1(); y <= validRange.GetY2(); y += kCoordsXYStep)
                 {
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetLeft(), y });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX1(), y });
                     if (surfaceElement != nullptr)
                     {
                         z1 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 3)), minHeight, maxHeight);
                         z2 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 2)), minHeight, maxHeight);
-                        res.Cost += SmoothLandRowByEdge(isExecuting, { validRange.GetLeft(), y }, z1, z2, -32, 0, 0, 1, 3, 2);
+                        res.Cost += SmoothLandRowByEdge(
+                            gameState, isExecuting, { validRange.GetX1(), y }, z1, z2, -32, 0, 0, 1, 3, 2);
                     }
 
-                    surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetRight(), y });
+                    surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX2(), y });
                     if (surfaceElement != nullptr)
                     {
                         z1 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 1)), minHeight, maxHeight);
                         z2 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 0)), minHeight, maxHeight);
-                        res.Cost += SmoothLandRowByEdge(isExecuting, { validRange.GetRight(), y }, z1, z2, 32, 0, 2, 3, 1, 0);
+                        res.Cost += SmoothLandRowByEdge(
+                            gameState, isExecuting, { validRange.GetX2(), y }, z1, z2, 32, 0, 2, 3, 1, 0);
                     }
                 }
 
-                for (int32_t x = validRange.GetLeft(); x <= validRange.GetRight(); x += kCoordsXYStep)
+                for (int32_t x = validRange.GetX1(); x <= validRange.GetX2(); x += kCoordsXYStep)
                 {
-                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ x, validRange.GetTop() });
+                    auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ x, validRange.GetY1() });
                     if (surfaceElement != nullptr)
                     {
                         z1 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 1)), minHeight, maxHeight);
                         z2 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 2)), minHeight, maxHeight);
-                        res.Cost += SmoothLandRowByEdge(isExecuting, { x, validRange.GetTop() }, z1, z2, 0, -32, 0, 3, 1, 2);
+                        res.Cost += SmoothLandRowByEdge(
+                            gameState, isExecuting, { x, validRange.GetY1() }, z1, z2, 0, -32, 0, 3, 1, 2);
                     }
 
-                    surfaceElement = MapGetSurfaceElementAt(CoordsXY{ x, validRange.GetBottom() });
+                    surfaceElement = MapGetSurfaceElementAt(CoordsXY{ x, validRange.GetY2() });
                     if (surfaceElement != nullptr)
                     {
                         z1 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 0)), minHeight, maxHeight);
                         z2 = std::clamp(
                             static_cast<uint8_t>(TileElementGetCornerHeight(surfaceElement, 3)), minHeight, maxHeight);
-                        res.Cost += SmoothLandRowByEdge(isExecuting, { x, validRange.GetBottom() }, z1, z2, 0, 32, 1, 2, 0, 3);
+                        res.Cost += SmoothLandRowByEdge(
+                            gameState, isExecuting, { x, validRange.GetY2() }, z1, z2, 0, 32, 1, 2, 0, 3);
                     }
                 }
                 break;
             }
-            case MAP_SELECT_TYPE_CORNER_0:
-            case MAP_SELECT_TYPE_CORNER_1:
-            case MAP_SELECT_TYPE_CORNER_2:
-            case MAP_SELECT_TYPE_CORNER_3:
+            case MapSelectType::corner0:
+            case MapSelectType::corner1:
+            case MapSelectType::corner2:
+            case MapSelectType::corner3:
             {
-                auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetLeft(), validRange.GetTop() });
+                auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX1(), validRange.GetY1() });
                 if (surfaceElement == nullptr)
                     break;
                 uint8_t newBaseZ = surfaceElement->BaseHeight;
                 uint8_t newSlope = surfaceElement->GetSlope();
+                auto direction = static_cast<Direction>(selectionType);
 
                 if (raiseLand)
                 {
-                    newSlope = RaiseSurfaceCornerFlags(selectionType, newSlope);
+                    newSlope = RaiseSurfaceCornerFlags(direction, newSlope);
                 }
                 else
                 {
-                    newSlope = LowerSurfaceCornerFlags(selectionType, newSlope);
+                    newSlope = LowerSurfaceCornerFlags(direction, newSlope);
                 }
 
                 if (newSlope & kTileSlopeRaiseOrLowerBaseHeight)
@@ -479,85 +488,91 @@ namespace OpenRCT2::GameActions
                 // Smooth the corners
                 int32_t z = MapGetCornerHeight(newBaseZ, newSlope, 2);
                 res.Cost += SmoothLandRowByCorner(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, -32, 0, 2);
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, -32, 0, 2);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 0);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 32, 2, 0);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 32, 2, 0);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 3);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 32, 1, 3);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 32, 1, 3);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 1);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, -32, 3, 1);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, -32, 3, 1);
 
                 // Smooth the edges
                 switch (selectionType)
                 {
-                    case MAP_SELECT_TYPE_CORNER_0:
+                    case MapSelectType::corner0:
                         z = MapGetCornerHeight(newBaseZ, newSlope, 0);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 0, 3, 0);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 0, 3, 0);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, 32, 1, 0);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, 32, 1, 0);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 3);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 0, 0, 3);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 0, 0, 3);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 1);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, -32, 0, 1);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, -32, 0, 1);
                         break;
-                    case MAP_SELECT_TYPE_CORNER_1:
+                    case MapSelectType::corner1:
                         z = MapGetCornerHeight(newBaseZ, newSlope, 1);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 0, 2, 1);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 0, 2, 1);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, -32, 0, 1);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, -32, 0, 1);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 2);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 0, 1, 2);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 0, 1, 2);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 0);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, 32, 1, 0);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, 32, 1, 0);
                         break;
-                    case MAP_SELECT_TYPE_CORNER_2:
+                    case MapSelectType::corner2:
                         z = MapGetCornerHeight(newBaseZ, newSlope, 2);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 0, 1, 2);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 0, 1, 2);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, -32, 3, 2);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, -32, 3, 2);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 1);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 0, 2, 1);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 0, 2, 1);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 3);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, 32, 2, 3);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, 32, 2, 3);
                         break;
-                    case MAP_SELECT_TYPE_CORNER_3:
+                    case MapSelectType::corner3:
                         z = MapGetCornerHeight(newBaseZ, newSlope, 3);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 0, 0, 3);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 0, 0, 3);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, 32, 2, 3);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, 32, 2, 3);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 0);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 0, 3, 0);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 0, 3, 0);
                         z = MapGetCornerHeight(newBaseZ, newSlope, 2);
                         res.Cost += SmoothLandRowByCorner(
-                            isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 0, -32, 3, 2);
+                            gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 0, -32, 3, 2);
+                        break;
+                    default:
                         break;
                 }
                 break;
             }
-            case MAP_SELECT_TYPE_EDGE_0:
-            case MAP_SELECT_TYPE_EDGE_1:
-            case MAP_SELECT_TYPE_EDGE_2:
-            case MAP_SELECT_TYPE_EDGE_3:
+            case MapSelectType::edge0:
+            case MapSelectType::edge1:
+            case MapSelectType::edge2:
+            case MapSelectType::edge3:
             {
                 // TODO: Handle smoothing by edge
                 // Get the two corners to raise
-                auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetLeft(), validRange.GetTop() });
+                auto surfaceElement = MapGetSurfaceElementAt(CoordsXY{ validRange.GetX1(), validRange.GetY1() });
                 if (surfaceElement == nullptr)
                     break;
                 uint8_t newBaseZ = surfaceElement->BaseHeight;
                 uint8_t oldSlope = surfaceElement->GetSlope();
-                int32_t rowIndex = selectionType - (MAP_SELECT_TYPE_EDGE_0 - MAP_SELECT_TYPE_FULL - 1);
+                int32_t rowIndex = EnumValue(selectionType)
+                    - (EnumValue(MapSelectType::edge0) - EnumValue(MapSelectType::full) - 1);
                 uint8_t newSlope = raiseLand ? RaiseSurfaceCornerFlags(rowIndex, oldSlope)
                                              : LowerSurfaceCornerFlags(rowIndex, oldSlope);
 
@@ -568,15 +583,15 @@ namespace OpenRCT2::GameActions
                     newSlope &= ~kTileSlopeRaiseOrLowerBaseHeight;
                 }
 
-                const uint8_t edge = selectionType - MAP_SELECT_TYPE_EDGE_0;
+                const uint8_t edge = EnumValue(selectionType) - EnumValue(MapSelectType::edge0);
 
                 // Table with corners for each edge selection. The first two are the selected corners, the latter
                 // two are the opposites
                 static constexpr uint8_t cornerIndices[][4] = {
-                    { 2, 3, 1, 0 }, // MAP_SELECT_TYPE_EDGE_0
-                    { 3, 0, 2, 1 }, // MAP_SELECT_TYPE_EDGE_1
-                    { 0, 1, 3, 2 }, // MAP_SELECT_TYPE_EDGE_2
-                    { 1, 2, 0, 3 }, // MAP_SELECT_TYPE_EDGE_3
+                    { 2, 3, 1, 0 }, // MapSelectType::edge0
+                    { 3, 0, 2, 1 }, // MapSelectType::edge1
+                    { 0, 1, 3, 2 }, // MapSelectType::edge2
+                    { 1, 2, 0, 3 }, // MapSelectType::edge3
                 };
                 // Big coordinate offsets for the neighbouring tile for the given edge selection
                 static constexpr CoordsXY stepOffsets[] = {
@@ -597,29 +612,32 @@ namespace OpenRCT2::GameActions
                 uint8_t z4 = MapGetCornerHeight(newBaseZ, newSlope, c4);
                 // Smooth the edge at the top of the new slope
                 res.Cost += SmoothLandRowByEdge(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z1, z2, stepOffsets[edge].x,
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z1, z2, stepOffsets[edge].x,
                     stepOffsets[edge].y, c3, c4, c1, c2);
                 // Smooth the edge at the bottom of the new slope
                 res.Cost += SmoothLandRowByEdge(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z3, z4, -stepOffsets[edge].x,
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z3, z4, -stepOffsets[edge].x,
                     -stepOffsets[edge].y, c1, c2, c3, c4);
 
                 // Smooth corners
                 res.Cost += SmoothLandRowByCorner(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z1, -stepOffsets[edge].y, stepOffsets[edge].x,
-                    c2, c1);
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z1, -stepOffsets[edge].y,
+                    stepOffsets[edge].x, c2, c1);
                 res.Cost += SmoothLandRowByCorner(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z2, stepOffsets[edge].y, -stepOffsets[edge].x,
-                    c1, c2);
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z2, stepOffsets[edge].y,
+                    -stepOffsets[edge].x, c1, c2);
                 int32_t z = MapGetCornerHeight(newBaseZ, newSlope, 2);
                 res.Cost += SmoothLandRowByCorner(
-                    isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, -32, 0, 2);
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, -32, 0, 2);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 0);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, 32, 2, 0);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, 32, 2, 0);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 3);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, -32, 32, 1, 3);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, -32, 32, 1, 3);
                 z = MapGetCornerHeight(newBaseZ, newSlope, 1);
-                res.Cost += SmoothLandRowByCorner(isExecuting, { validRange.GetLeft(), validRange.GetTop() }, z, 32, -32, 3, 1);
+                res.Cost += SmoothLandRowByCorner(
+                    gameState, isExecuting, { validRange.GetX1(), validRange.GetY1() }, z, 32, -32, 3, 1);
                 break;
             }
             default:
@@ -633,13 +651,13 @@ namespace OpenRCT2::GameActions
         {
             auto raiseLandAction = LandRaiseAction({ _coords.x, _coords.y }, validRange, selectionType);
             raiseLandAction.SetFlags(GetFlags());
-            result = isExecuting ? ExecuteNested(&raiseLandAction) : QueryNested(&raiseLandAction);
+            result = isExecuting ? ExecuteNested(&raiseLandAction, gameState) : QueryNested(&raiseLandAction, gameState);
         }
         else
         {
             auto lowerLandAction = LandLowerAction({ _coords.x, _coords.y }, validRange, selectionType);
             lowerLandAction.SetFlags(GetFlags());
-            result = isExecuting ? ExecuteNested(&lowerLandAction) : QueryNested(&lowerLandAction);
+            result = isExecuting ? ExecuteNested(&lowerLandAction, gameState) : QueryNested(&lowerLandAction, gameState);
         }
         if (result.Error != Status::Ok)
         {
@@ -648,7 +666,7 @@ namespace OpenRCT2::GameActions
 
         if (isExecuting)
         {
-            Audio::Play3D(Audio::SoundId::PlaceItem, { _coords.x, _coords.y, centreZ });
+            Audio::Play3D(Audio::SoundId::placeItem, { _coords.x, _coords.y, centreZ });
         }
         res.Cost += result.Cost;
         return res;
